@@ -634,11 +634,15 @@ sub rockchip_dtb_setup {
 	if ($kernel_version =~ /rockchip/){
 	print "kernel is rockchip\n";
 		if ($zfs == '1') {
-			syscmd("mount $espdev $targetdir/boot/efi/");
-			syscmd("cp -r /cdrom/dtb $targetdir/boot/efi/");
-			syscmd("umount -l $targetdir/boot/efi/") ;
+			syscmd("mount $espdev $targetdir/boot/efi/")  ||
+				die "unable to mount ESP  on '$espdev'\n";
+			syscmd("cp -r /cdrom/dtb $targetdir/boot/efi/") ||
+				die "copy dtbs to '$espdev'\n";
+			syscmd("umount -l $targetdir/boot/efi/") ||
+				die "unable to umount ESP  on '$espdev'\n";
 		}else{
-			syscmd("cp -r /cdrom/dtb $targetdir/boot/efi/");
+			syscmd("cp -r /cdrom/dtb $targetdir/boot/efi/") ||
+				die "copy dtbs to '$espdev'\n";
 		}
 	}
 }
@@ -671,7 +675,9 @@ sub prepare_grub_efi_boot_esp {
 		my $rc = syscmd("chroot $targetdir /usr/sbin/grub-install --target loongarch64-efi --no-floppy --bootloader-id='proxmox' $dev");
 	} elsif ($arch eq "riscv64"){
 		my $rc = syscmd("chroot $targetdir /usr/sbin/grub-install --target riscv64-efi --no-floppy --bootloader-id='proxmox' $dev");
-	} else {
+	} elsif ($arch eq "x86_64"){
+                my $rc = syscmd("chroot $targetdir /usr/sbin/grub-install --target x86_64-efi --no-floppy --bootloader-id='proxmox' $dev");
+        } else {
 		die "unable to install grub on arch $arch\n";
 	}
 	if ($rc != 0) {
@@ -688,7 +694,7 @@ sub prepare_grub_efi_boot_esp {
 	mkdir("$targetdir/boot/efi/EFI/BOOT");
 	syscmd("cp -r $targetdir/boot/efi/EFI/proxmox/* $targetdir/boot/efi/EFI/BOOT/");
 	if ($arch eq "aarch64"){
-		syscmd("cp $targetdir/boot/efi/EFI/BOOT/grubaa64.efi $targetdir/boot/efi/EFI/BOOT/BOOTAA64.EFI ") == 0  ||
+		syscmd("cp $targetdir/boot/efi/EFI/BOOT/grubaa64.efi $targetdir/boot/efi/EFI/BOOT/BOOAA64.EFI ") == 0  ||
 	    die "unable to copy efi boot loader\n";
 	} elsif ($arch eq "loongarch64") { 
 		syscmd("cp $targetdir/boot/efi/EFI/BOOT/grubloongarch64.efi $targetdir/boot/efi/EFI/BOOT/BOOTLOONGARCH64.efi") == 0  ||
@@ -696,7 +702,10 @@ sub prepare_grub_efi_boot_esp {
 	} elsif ($arch eq "riscv64") {
 		syscmd("cp $targetdir/boot/efi/EFI/BOOT/grubriscv64.efi $targetdir/boot/efi/EFI/BOOT/BOOTRISCV64.efi") == 0  ||
             die "unable to copy efi boot loader\n";
-	}  else {
+	} elsif ($arch eq "x86_64") {
+                syscmd("cp $targetdir/boot/efi/EFI/BOOT/grubx64.efi $targetdir/boot/efi/EFI/BOOT/BOOTX64.efi") == 0  ||
+            die "unable to copy efi boot loader\n";
+	} else {
                 die "unable to opy efi boot loader on arch $arch\n";
         }
     };
@@ -1383,7 +1392,7 @@ _EOD
 	diversion_remove($targetdir, "/usr/sbin/update-grub");
 	diversion_remove($targetdir, "/usr/sbin/update-initramfs");
 
-
+	my $arch = get_host_arch();
 	if (!is_test_mode()) {
 
 	    unlink ("$targetdir/etc/mtab");
@@ -1407,8 +1416,9 @@ _EOD
 		    } else {
 			if (!$native_4k_disk_bootable) {
 			    eval {
-#				syscmd("chroot $targetdir /usr/sbin/grub-install --target i386-pc --no-floppy --bootloader-id='proxmox' $dev") == 0 ||
-					print ("not need  install the i386-pc boot loader on '$dev'\n");
+				if ($arch eq 'x86_64'){
+					syscmd("chroot $targetdir /usr/sbin/grub-install --target i386-pc --no-floppy --bootloader-id='proxmox' $dev") 
+				}
 			    };
 			    push @$bootloader_err_list, $@ if $@;
 			}
@@ -1495,12 +1505,26 @@ _EOD
 	    file_write_all("$targetdir/$user_cfg_fn", "user: root\@pam\n\temail ${mailto}\n");
 	    chroot_chown($targetdir, $user_cfg_fn, user => 'root', group => 'backup');
 	    chroot_chmod($targetdir, $user_cfg_fn, mode => '0640');
+	} elsif ($iso_env->{product} eq 'pdm') {
+	    my $base_cfg_path = "/etc/proxmox-datacenter-manager";
+	    mkdir "$targetdir/$base_cfg_path";
+	    mkdir "$targetdir/$base_cfg_path/access";
+
+	    my $access_dir_fn = "$base_cfg_path/access";
+	    my $user_cfg_fn = "$access_dir_fn/user.cfg";
+	    file_write_all("$targetdir/$user_cfg_fn", "user: root\@pam\n\temail ${mailto}\n");
+
+	    chroot_chown($targetdir, $base_cfg_path, user => 'www-data', recursive => 1);
+	    chroot_chmod($targetdir, $base_cfg_path, mode => '01770');
+	    chroot_chown($targetdir, $access_dir_fn, user => 'root', group => 'www-data', recursive => 1);
+	    chroot_chmod($targetdir, $access_dir_fn, mode => '0750');
+	    chroot_chmod($targetdir, $user_cfg_fn, mode => '0640');
 	}
     };
 
     my $err = $@;
 
-    update_progress(1, 0, 1, "");
+    update_progress(1, 0, 1, "installation finished");
 
     print STDERR $err if $err && $err ne "\n";
 
