@@ -11,18 +11,22 @@ use std::{
 };
 
 use proxmox_auto_installer::{
-    answer::Answer,
-    answer::FilterMatch,
+    answer::{Answer, FilterMatch},
     sysinfo::SysInfo,
     utils::{
-        get_matched_udev_indexes, get_nic_list, get_single_udev_index, AutoInstSettings,
-        FetchAnswerFrom, HttpOptions,
+        get_matched_udev_indexes, get_nic_list, get_single_udev_index,
+        verify_email_and_root_password_settings, verify_first_boot_settings,
+        verify_locale_settings, AutoInstSettings, FetchAnswerFrom, HttpOptions,
     },
 };
 use proxmox_installer_common::{FIRST_BOOT_EXEC_MAX_SIZE, FIRST_BOOT_EXEC_NAME};
 
 static PROXMOX_ISO_FLAG: &str = "/auto-installer-capable";
 
+/// Locale information as raw JSON, can be parsed into a
+/// [LocaleInfo](`proxmox_installer_common::setup::LocaleInfo`) struct.
+const LOCALE_INFO: &str = include_str!("../../locale-info.json");
+
 /// This tool can be used to prepare a Proxmox installation ISO for automated installations.
 /// Additional uses are to validate the format of an answer file or to test match filters and
 /// print information on the properties to match against for the current hardware.
@@ -53,10 +57,10 @@ struct CommandDeviceInfo {
 /// Test which devices the given filter matches against
 ///
 /// Filters support the following syntax:
-/// ?          Match a single character
-/// *          Match any number of characters
-/// [a], [0-9] Specific character or range of characters
-/// [!a]       Negate a specific character of range
+/// - `?`               Match a single character
+/// - `*`               Match any number of characters
+/// - `[a]`, `[0-9]`  Specific character or range of characters
+/// - `[!a]`          Negate a specific character of range
 ///
 /// To avoid globbing characters being interpreted by the shell, use single quotes.
 /// Multiple filters can be defined.
@@ -64,7 +68,9 @@ struct CommandDeviceInfo {
 /// Examples:
 /// Match disks against the serial number and device name, both must match:
 ///
+/// ```sh
 /// proxmox-auto-install-assistant match --filter-match all disk 'ID_SERIAL_SHORT=*2222*' 'DEVNAME=*nvme*'
+/// ```
 #[derive(Args, Debug)]
 #[command(verbatim_doc_comment)]
 struct CommandDeviceMatch {
@@ -587,9 +593,13 @@ fn parse_answer(path: impl AsRef<Path> + fmt::Debug) -> Result<Answer> {
     if let Err(err) = file.read_to_string(&mut contents) {
         bail!("Reading from file {path:?} failed: {err}");
     }
+
     match toml::from_str(&contents) {
         Ok(answer) => {
-            println!("The file was parsed successfully, no syntax errors found!");
+            verify_locale_settings(&answer, &serde_json::from_str(LOCALE_INFO)?)?;
+            verify_first_boot_settings(&answer)?;
+            verify_email_and_root_password_settings(&answer)?;
+            println!("The answer file was parsed successfully, no errors found!");
             Ok(answer)
         }
         Err(err) => bail!("Error parsing answer file: {err}"),
