@@ -99,7 +99,7 @@ struct ProductInfo {
 }
 
 /// The current kernel version.
-/// Aligns with the format as used by the /nodes/<node>/status API of each product.
+/// Aligns with the format as used by the `/nodes/<node>/status` API of each product.
 #[derive(Serialize)]
 struct KernelVersionInformation {
     /// The systemname/nodename
@@ -168,8 +168,8 @@ struct PostHookInfo {
     schema: PostHookInfoSchema,
     /// major.minor version of Debian as installed, retrieved from /etc/debian_version
     debian_version: String,
-    /// PVE/PMG/PBS version as reported by `pveversion`, `pmgversion` or
-    /// `proxmox-backup-manager version`, respectively.
+    /// PVE/PMG/PBS/PDM version as reported by `pveversion`, `pmgversion`,
+    /// `proxmox-backup-manager version` or `proxmox-datacenter-manager version`, respectively.
     product: ProductInfo,
     /// Release information for the ISO used for the installation.
     iso: IsoInfo,
@@ -400,6 +400,7 @@ impl PostHookInfo {
             ProxmoxProduct::PVE => "pve-manager",
             ProxmoxProduct::PMG => "pmg-api",
             ProxmoxProduct::PBS => "proxmox-backup-server",
+            ProxmoxProduct::PDM => "proxmox-datacenter-manager",
         };
 
         let version = run_cmd(&[
@@ -422,14 +423,14 @@ impl PostHookInfo {
     ///
     /// First, it determines the exact path to the kernel image (aka. `/boot/vmlinuz-<version>`)
     /// by looking at the installed kernel package, then reads the string directly from the image
-    /// from the well-defined kernel header. See also [0] for details.
-    ///
-    /// [0] https://www.kernel.org/doc/html/latest/arch/x86/boot.html
+    /// from the [well-defined kernel header].
     ///
     /// # Arguments
     ///
     /// * `run_cmd` - Callback to run a command inside the target chroot.
     /// * `open_file` - Callback to open a file inside the target chroot.
+    ///
+    /// [well-defined kernel header]: https://www.kernel.org/doc/html/latest/arch/x86/boot.html
     ///#[cfg(target_arch = "x86_64")] This function call was removed before, so it is safe
     fn gather_kernel_version(
         run_cmd: &dyn Fn(&[&str]) -> Result<String>,
