@@ -205,15 +205,15 @@ fn installer_setup_late(siv: &mut Cursive) {
         );
     }
 
-    // if state.setup_info.config.product == ProxmoxProduct::PVE && !state.runtime_info.hvm_supported {
-    //     display_setup_warning(
-    //         siv,
-    //         concat!(
-    //             "No support for hardware-accelerated KVM virtualization detected.\n\n",
-    //             "Check BIOS settings for Intel VT / AMD-V / SVM."
-    //         ),
-    //     );
-    // }
+    if state.setup_info.config.product == ProxmoxProduct::PVE && !state.runtime_info.hvm_supported {
+        display_setup_warning(
+            siv,
+            concat!(
+                "No support for hardware-accelerated KVM virtualization detected.\n\n",
+                "Check BIOS settings for Intel VT / AMD-V / SVM."
+            ),
+        );
+    }
 }
 
 fn initial_setup_error(siv: &mut CursiveRunnable, message: &str) -> ! {
